<?php

namespace Litecms\Tradehistory\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Tradehistory\Models\TradeHistory;

class TradeHistoryPolicy
{

    /**
     * Determine if the given user can view the trade_history.
     *
     * @param UserPolicy $user
     * @param TradeHistory $trade_history
     *
     * @return bool
     */
    public function view(UserPolicy $user, TradeHistory $trade_history)
    {
        if ($user->canDo('tradehistory.trade_history.view') && $user->isAdmin()) {
            return true;
        }

        return $trade_history->user_id == user_id() && $trade_history->user_type == user_type();
    }

    /**
     * Determine if the given user can create a trade_history.
     *
     * @param UserPolicy $user
     * @param TradeHistory $trade_history
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('tradehistory.trade_history.create');
    }

    /**
     * Determine if the given user can update the given trade_history.
     *
     * @param UserPolicy $user
     * @param TradeHistory $trade_history
     *
     * @return bool
     */
    public function update(UserPolicy $user, TradeHistory $trade_history)
    {
        if ($user->canDo('tradehistory.trade_history.edit') && $user->isAdmin()) {
            return true;
        }

        return $trade_history->user_id == user_id() && $trade_history->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given trade_history.
     *
     * @param UserPolicy $user
     * @param TradeHistory $trade_history
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, TradeHistory $trade_history)
    {
        return $trade_history->user_id == user_id() && $trade_history->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given trade_history.
     *
     * @param UserPolicy $user
     * @param TradeHistory $trade_history
     *
     * @return bool
     */
    public function verify(UserPolicy $user, TradeHistory $trade_history)
    {
        if ($user->canDo('tradehistory.trade_history.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given trade_history.
     *
     * @param UserPolicy $user
     * @param TradeHistory $trade_history
     *
     * @return bool
     */
    public function approve(UserPolicy $user, TradeHistory $trade_history)
    {
        if ($user->canDo('tradehistory.trade_history.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
